pub struct WorkerPool {
catalog: &'static ContentCatalog,
limiter: Arc<WorkerLimiter>,
completed_chunks: Arc<AtomicU64>,
sims_completed: Arc<AtomicU64>,
work_tx: Option<Sender<WorkBatch>>,
result_rx: Option<Receiver<WorkBatchResult>>,
resolver: Option<Arc<DynDataResolver<'static>>>,
}Expand description
Thread pool that executes simulation chunks across available CPU cores.
Fields
catalog: &'static ContentCataloglimiter: Arc<WorkerLimiter>completed_chunks: Arc<AtomicU64>sims_completed: Arc<AtomicU64>work_tx: Option<Sender<WorkBatch>>result_rx: Option<Receiver<WorkBatchResult>>resolver: Option<Arc<DynDataResolver<'static>>>Implementations
Sourceimpl WorkerPool
impl WorkerPool
pub fn new(max_workers: usize, catalog: &'static ContentCatalog) -> Self
pub fn set_resolver<R>(&mut self, resolver: R)
Sourcepub fn start(&mut self, handle: &Handle)
pub fn start(&mut self, handle: &Handle)
Starts worker tasks on handle.
Panics
Panics if no resolver was configured before starting the pool.
pub fn result_rx(&mut self) -> Option<Receiver<WorkBatchResult>>
pub fn work_tx(&self) -> Option<Sender<WorkBatch>>
Sourcepub fn set_max_workers(&self, max_workers: usize)
pub fn set_max_workers(&self, max_workers: usize)
Update the maximum number of concurrently executing work items.
pub fn stats(&self) -> NodeStats
pub(crate) fn set_dyn_resolver( &mut self, resolver: Arc<DynDataResolver<'static>>, )